@@ -22,6 +22,7 @@ SpeedoMeter::SpeedoMeter(QWidget *parent) :
     ui->lcdNumber_3->setDigitCount(7);
     ui->lcdNumber_2->setDigitCount(7);
     ui->lcdNumber->setDigitCount(7);
+    ui->lcdNumber_4->setDigitCount(10);
 
     // load total distance from a file
     FILE *fp=fopen("/home/user/.speedrec","r");
@@ -30,10 +31,14 @@ SpeedoMeter::SpeedoMeter(QWidget *parent) :
         fscanf(fp,"%f",&total);
         fclose(fp);
     }
-
+    hour=min=sec=tensofsec=0;
+    started=0;paused=0;
     QTimer *t=new QTimer(this);
-    connect(t,SIGNAL(timeout()),this,SLOT(updateTime()) );
+    connect(t,SIGNAL(timeout()),this,SLOT(updateLocation()) );
     t->start(1000);
+    QTimer *t2=new QTimer(this);
+    connect(t2,SIGNAL(timeout()),this,SLOT(updateTime()) );
+    t2->start(100);
 
 }
 
@@ -69,7 +74,7 @@ void SpeedoMeter::start_gps()
 {
    initLocation();
 }
-void SpeedoMeter::updateTime()
+void SpeedoMeter::updateLocation()
 {
     speed = locationModuleVar_Speed;
     //speed++;
@@ -117,8 +122,48 @@ void SpeedoMeter::updateTime()
 
 }
 
+void SpeedoMeter::updateTime()
+{
+
+char buf[80];char h[3],m[3],s[3];
+if(hour<10)sprintf(h,"0%d",hour);else sprintf(h,"%d",hour);
+if(min<10)sprintf(m,"0%d",min);else sprintf(m,"%d",hour);
+if(sec<10)sprintf(s,"0%d",sec);else sprintf(s,"%d",sec);
+
+sprintf(buf,"%s.%s.%s.%d",h,m,s,tensofsec);
+ui->lcdNumber_4->display(QString(buf));
+    if(!started)return;
+    if(paused)return;
+    tensofsec++;
+    if(tensofsec==10)
+    {
+       tensofsec=0;sec++;
+       if(sec==60)
+       {
+           sec=0;min++;
+           if(min==60)
+           {
+               min=0;hour++;
+           }
+       }
+    }
+
+}
 
 void SpeedoMeter::on_pushButton_2_clicked()
 {
     unit = 1-unit; // 0 km, 1-miles
 }
+
+void SpeedoMeter::on_startTimeButton_clicked()
+{
+    started=1;paused=0;
+
+}
+
+void SpeedoMeter::on_pauseTimeButton_clicked()
+{
+    if(paused){hour=min=sec=tensofsec=0;started=0;}
+    paused=1-paused;
+
+}
